@@ -18,6 +18,7 @@ from scipy import interpolate as interp
 from george.modeling import Model
 import extinction
 import emcee
+import pkg_resources
 
 # Define a few important constants that will be used later
 epsilon = 0.001
@@ -232,7 +233,8 @@ def generate_template(filter_wv, sn_type):
         interpolated template
     '''
 
-    template = np.load('./template/smoothed_sn' + sn_type + '.npz')
+    my_template_file = pkg_resources.resource_filename('extrabol.template_bank', 'smoothed_sn' + sn_type + '.npz')
+    template = np.load(my_template_file)
     temp_times = template['time']
     temp_wavelength = template['wavelength']
     temp_f_lambda = template['f_lambda']
@@ -551,7 +553,6 @@ def interpolate(lc, wv_corr, sn_type, use_mean, z):
     # Populate dense_lc with newly gp-predicted values
     for jj in np.arange(nfilts):
         gind = np.where(np.abs(x_pred[:, 1]-ufilts[jj]) < epsilon)[0]
-        print(np.shape(gind),np.shape(dense_fluxes[:,int(jj)]))
         dense_fluxes[:, int(jj)] = pred[gind]
         dense_errs[:, int(jj)] = np.sqrt(pred_var[gind])
     dense_lc = np.dstack((dense_fluxes, dense_errs))
@@ -880,10 +881,11 @@ def write_output(lc, dense_lc, Tarr, Terr_arr, Rarr, Rerr_arr,
 
 def main():
 
+    default_data = pkg_resources.resource_filename('extrabol.example', 'PSc000174_extrabol.dat')
     # Define all arguments
     parser = argparse.ArgumentParser(description='extrabol helpers')
     parser.add_argument('snfile', nargs='?',
-                        default='./example/PSc000174_extrabol.dat',
+                        default=default_data,
                         type=str, help='Give name of SN file')
     parser.add_argument('-m', '--mean', dest='mean', type=str, default='0',
                         help="Template function for gp.\
